==> haskell-base-prelude-1.4-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-prelude
version:              1.4
visibility:           public
id:                   base-prelude-1.4-wnQZLjYbC0AMx10nDA4zk
key:                  base-prelude-1.4-wnQZLjYbC0AMx10nDA4zk
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/base-prelude 
synopsis:
    The most complete prelude formed solely from the "base" package

description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.

    This package will never have any dependencies other than \"base\".

    /Versioning policy/

    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.

category:             Prelude
abi:                  0f4cc2a00394ac3934b038cb8a3b50e5
exposed:              True
exposed-modules:      BasePrelude
import-dirs:          /usr/lib/ghc-9.0.1/site-local/base-prelude-1.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/base-prelude-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/base-prelude-1.4
hs-libraries:         HSbase-prelude-1.4-wnQZLjYbC0AMx10nDA4zk
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock

haddock-html:         /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-prelude-1.4-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-prelude
version:              1.4
visibility:           public
id:                   base-prelude-1.4-2BOM8BPgshJ3XugpQGCzYd
key:                  base-prelude-1.4-2BOM8BPgshJ3XugpQGCzYd
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/base-prelude 
synopsis:
    The most complete prelude formed solely from the "base" package

description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.

    This package will never have any dependencies other than \"base\".

    /Versioning policy/

    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.

category:             Prelude
abi:                  9bdd2cba8186f4029f91353ed535e53c
exposed:              True
exposed-modules:      BasePrelude
import-dirs:          /usr/lib/ghc-9.0.2/site-local/base-prelude-1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/base-prelude-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/base-prelude-1.4
hs-libraries:         HSbase-prelude-1.4-2BOM8BPgshJ3XugpQGCzYd
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock

haddock-html:         /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
